==> absence_v2.0.tar.gz: config.tcl <==
###
### this is the master config file for all "absence" scripts
###

#######################################################################
# can be either "german" or "english"
# if german, then the files ".feiertage", ".messen", and ".abwesenheit_colors"
# are used,
# if english, then ".holidays" and ".tradeshows", and ".absence_colors"
# also mail_subject, recipient, KW_LAB, and rpc_port get changed
set language "german"

#######################################################################
# either define a server in yellow-pages, or add to everyones /etc/services
# file
#
if {$language == "german"} {
	set rpc_port abwesenheit
} else {
	set rpc_port absence
}

#######################################################################
# either define a server in yellow-pages, or add to everyones /etc/services
# file
#
if {$language == "german"} {
	set KW_LAB "KW"
} else {
	set KW_LAB "CW"
}

#######################################################################
# you will have to change this...
set server_name nasaxp

#######################################################################
# set the following to the command that you can use to send a mail in the
# following manner: mail -s "subject here" recipient
#
set os_name [exec uname]
if {$os_name == "OSF1"} {
	set mail_cmd "Mail"
} else {
	set mail_cmd "mail"
}

#######################################################################
# you may want to change this ... set to the dirs where
# the executables uname,date,rm,echo,grep, and ypcat can be found
#
set env(PATH) "/usr/sbin:/usr/bin:/usr/local/bin"

#######################################################################
# 'abwesenheit' is set up as an alias for sendmail, you may want to
# change this
#
if {$language == "german"} {
	set recipient "abwesenheit"
} else {
	set recipient "absence"
}

#######################################################################
# this is only for 'server', you may want to change it
set data_dir /ossc/local/Wesen

#######################################################################
# you will probably want to change this...
if {$language == "german"} {
	set mail_subject "OSSC Abwesenheit fuer KW "
} else {
	set mail_subject "Absences for the Calendar Week "
}

#######################################################################
# you may need to change this
set user_lookup "YP";	# set to "LOCAL" otherwise

==> absence_v2.1.tar.gz: config.tcl <==
###
### this is the master config file for all "absence" scripts
###

#######################################################################
# can be either "german" or "english"
# if german, then the files ".feiertage", ".messen", and ".abwesenheit_colors"
# are used,
# if english, then ".holidays" and ".tradeshows", and ".absence_colors"
# also mail_subject, recipient, and rpc_port get changed
# SERVER
set language "german"

#######################################################################
# either define a server in yellow-pages, or add to everyones /etc/services
# file
# ALL
if {$language == "german"} {
	set rpc_port abwesenheit
} else {
	set rpc_port absence
}

#######################################################################
# the number of days to be displayed
# SERVER
set num_cells 240

#######################################################################
# set the following to the command that you can use to send a mail in the
# following manner: mail -s "subject here" recipient
# SERVER
set os_name [exec uname]
if {$os_name == "OSF1"} {
	set mail_cmd "Mail"
} else {
	set mail_cmd "mail"
}

#######################################################################
# you may want to change this ... set to the dirs where
# the executables uname,date,rm,echo,grep, and ypcat can be found
# ALL
set env(PATH) "/usr/sbin:/usr/bin:/usr/local/bin"

#######################################################################
# 'abwesenheit' is set up as an alias for sendmail, you may want to
# change this
#
if {$language == "german"} {
	set recipient "abwesenheit"
} else {
	set recipient "absence"
}

#######################################################################
# this is only for 'server', you may want to change it
# SERVER
set data_dir /ossc/local/Wesen

#######################################################################
# you will probably want to change this...
# SERVER?
if {$language == "german"} {
	set mail_subject "OSSC Abwesenheit fuer KW "
} else {
	set mail_subject "Absences for the Calendar Week "
}

#######################################################################
# you may need to change this
# SERVER
set user_lookup "YP";	# set to "LOCAL" otherwise

#######################################################################
# you will have to change this...
# CLIENTS
set server_name nasaxp

#######################################################################
# font(s)
# CLIENTS
set prop_font	"-Adobe-times-medium-r-normal--*-180*"
